from datetime import date, datetime
from os import getenv

import awswrangler as wr
from airflow import DAG
from airflow.operators.python import PythonOperator

from mycroft.common import aws_s3, settings

REGION = getenv("REGION", "us-east-1")
STAGE = getenv("STAGE")
S3_BUCKET = getenv("RULES_POOL_BUCKET", "cdca-prod-us-east-1-intermediate-data")
# S3_BUCKET = "gdev4-policysuggestion-infra-intermediate-data-bucket"
# https://cdca-prod-us-east-1-intermediate-data.s3.amazonaws.com/2022-03-01/rules_pool/it_tools/recommendations.csv
OUTPUT_RECOMMENDATIONS_KEY = f"{date.today()}/recommendations.csv"
NAMESPACE = getenv("NAMESPACE")


def extract_recommendations(env: str, org_id: int, **kwargs):
    # load existing recommendations
    aws_data = aws_s3.AwsS3({})
    df = aws_data.get_dataframe_from_s3(S3_BUCKET, OUTPUT_RECOMMENDATIONS_KEY)

    # apply filter
    df = df[(df["org_id"] == org_id) & (df["env"] == env)]

    # ISO formatted date
    current_date = date.today().isoformat()[:10]
    # write results to csv files on s3
    prefix = "policy_automation/threatsight"
    wr.s3.to_csv(
        df=df,
        path=f"s3://{S3_BUCKET}/{prefix}/env={env}/org_id={org_id}/event_date={current_date}/recs.csv",
    )


args = {
    "owner": "airflow",
    "project": "policy_automation",
}


with DAG(
    dag_id="ts_data_sharing",
    default_args=args,
    start_date=datetime(2021, 2, 26),
    schedule_interval=None,
    is_paused_upon_creation=False,
) as dag:
    orgs = [
        ("prd5use1", "prod05", 3256),
        ("prd2use1", "prod02", 1222),
        ("prd5use1", "prod05", 19150),
    ]
    for namespace, env, org_id in orgs:
        if namespace in NAMESPACE:
            fetch = PythonOperator(
                task_id=f"extract_{env}_{org_id}",
                provide_context=True,
                python_callable=extract_recommendations,
                op_kwargs={"env": env, "org_id": org_id},
            )
if __name__ == "__main__":
    dag.cli()
