import logging
import os
from datetime import date, datetime, timedelta

from airflow import DAG
from airflow.operators.python import PythonOperator

from mycroft.common import settings
from mycroft.common.gen_mature_org_list import gen_mature_org_list

logger = logging.getLogger()

# Default airflow dag arguements
default_args = {
    "owner": "airflow",
    "project": "policy_automation",
    "email_on_failure": False,
    "email_on_retry": False,
    "retries": 3,
    "retry_delay": timedelta(minutes=5),
}

# Define the dag
dag = DAG(
    dag_id="generate_org_maturity_list",
    description="Generates Org Maturity List",
    default_args=default_args,
    schedule_interval=None,  # schedule this task at 23:05
    start_date=datetime(2021, 3, 31),
    catchup=False,
    is_paused_upon_creation=False,
)

region = os.getenv("REGION", "us-east-1")
# query_output_s3_bucket = os.getenv(
#     "QUERY_OUTPUT_BUCKET", "s3://cdca-policy-suggest-analytics-dev-athena-outputs"
# )
query_output_s3_bucket = os.getenv(
    "QUERY_OUTPUT_BUCKET", "s3://gdev4-policysuggestion-infra-athena-bucket"
)

for k, v in sorted(os.environ.items()):
    logger.info(f"env var: {k} : {v}")

stage = os.getenv("STAGE")
active_envs = []
if stage == "dev":
    database = "cdca"
else:
    database = "athena"
# events_s3_bucket = os.getenv(
#     "EVENTS_POOL_BUCKET", "s3://cdca-prod-us-east-1-intermediate-data/mature_org_db/"
# )
events_s3_bucket = os.getenv(
    "EVENTS_POOL_BUCKET",
    "s3://gdev4-policysuggestion-infra-intermediate-data-bucket/mature_org_db/",
)
policy_table = os.getenv("BASELINE_POLICY_TABLENAME", "policy_view")
policy_override_table = os.getenv(
    "BASELINE_REPUTATION_TABLENAME", "policy_org_reputation_override"
)
output_s3_bucket = f"s3://{events_s3_bucket}/mature_org_db/"
end_time = date.today() - timedelta(days=1)
start_time = end_time - timedelta(weeks=1)

# TODO: Remove unused DAG component
generate_mature_org_list = PythonOperator(
    task_id="generate_mature_org_list",
    python_callable=gen_mature_org_list,
    dag=dag,
    op_kwargs={
        "region": region,
        "envs": active_envs,
        "database": database,
        "policy_override_table": policy_override_table,
        "policy_table": policy_table,
        "query_output_bucket": query_output_s3_bucket.replace("s3://", ""),
        "query_output_folder": "",
        "query_output_location": query_output_s3_bucket,
        "start_time": start_time,
        "end_time": end_time,
        "output_s3_bucket": output_s3_bucket,
    },
    retries=3,
)
